/**
IBM SOFTWARE DISCLAIMER 

Java array package (draft 0.2). Copyright (1998), International Business 
Machines Corporation.

Permission to use, copy, modify and distribute this software for any
noncommercial purpose and without fee is hereby granted, provided that
this copyright and permission notice appear on all copies of the
software. The name of the IBM Corporation may not be used in any
advertising or publicity pertaining to the use of the software. IBM
makes no warranty or representations about the suitability of the
software for any purpose.  It is provided "AS IS" without any express
or implied warranty, including the implied warranties of
merchantability, fitness for a particular purpose and non-infringement.
IBM shall not be liable for any direct, indirect, special or
consequential damages resulting from the loss of use, data or projects,
whether in an action of contract or tort, arising out of or in
connection with the use or performance of this software.
*/

package array;

/**
   doubleArray = abstract class for arrays of doubles
   <P>
   The doubleArray abstract class is the parent class of all concrete
   arrays of doubles. 
   It implements the Array.getAsObject and Array.setToObject
   methods of interface Array.
   It also declares the methods get and set, that must be
   implemented by all doubleArray&lt;rank&gt; classes.
   <P>
   The following &lt;rank&gt;s are valid:
   <P>
   0D (for 0-dimensional arrays), 1D (for 1-dimensional arrays), 
   2D, 3D, 4D, 5D, 6D, 7D.
*/

public abstract class doubleArray implements Array {

    /**
       Return the value of an element of the array.
       @param index	index[i] = index along i-th axis, 0 <= index[i] < size(i)
       @exception InvalidArrayIndexException index[] must be of length equal to rank
    */
    public abstract double get(int[] index) 
	throws InvalidArrayIndexException, ArrayIndexOutOfBoundsException;

    /**
       Set the value of an element of the array.
       @param index	index[i] = index along i-th axis, 0 <= index[i] < size(i)
       @param d		value to which element is set
       @exception InvalidArrayIndexException index[] must be of length equal to rank
    */
    public abstract void set(int [] index, double d) 
	throws InvalidArrayIndexException, ArrayIndexOutOfBoundsException;

     /**
       Return a Double object which has the same value as the 
       specified element of the array.
       @param index	index[i] = index along i-th axis, 0 <= index[i] < size(i)
       @exception InvalidArrayIndexException index[] must be of length equal to rank
    */
    public Object getAsObject(int[] index)
	throws InvalidArrayIndexException, ArrayIndexOutOfBoundsException {

	return new Double(get(index));
    }

    /**
       Sets the specified element of the array to a particular value.
       @param index	index[i] = index along i-th axis, 0 <= index[i] < size(i)
       @param obj	the array element is set to the value of this Object
       @exception InvalidArrayIndexException index[] must be of length equal to rank
    */
    public void setToObject(int[] index, Object obj) 
	throws InvalidArrayIndexException, ArrayIndexOutOfBoundsException,
	       NullPointerException {

	Double d = (Double)obj;
	set(index,d.doubleValue());
    }
}

    
